#!/usr/bin/env python3
import logging
import paramiko
import re

from .summer import VolumeCollection, Volume
from .functions import to_bytes

logger = logging.getLogger(name="summmo")

"""
Classe pour gérer un endpoint
"""
class SummerEndpoint():
    def __init__(self, prefix, server, username, port=22, password=""):
        """
        Définition du endpoint
        prefix: Un prefixe pour le nom de tous les volumes trouvés dans ce endpoint
        uri: URI de connexion par exemple vsadmin@sum-resif-admin.ujf-grenoble.fr
        """
        self.prefix = prefix
        self.server = server
        self.port = port
        self.username = username
        self.password = password
        self.client = paramiko.SSHClient()
        self.client.load_system_host_keys()
        self.client.set_missing_host_key_policy(paramiko.client.AutoAddPolicy)
        self.volumes = VolumeCollection()
        self._fetch_volumes()

    def _fetch_volumes(self):
        self.client.connect(self.server, port=self.port, username=self.username, password=self.password, allow_agent=False, look_for_keys=False)
        _, ssh_stdout, _ = self.client.exec_command("volume show")
        for eline in ssh_stdout.readlines():
            if "_nfs_" in eline:
                logger.debug(eline)
                vol = Volume(eline.split(' ')[1])
                logger.debug(vol)
                self.volumes.add_volume(vol)

    def fetch_data(self):
        """
        Connexion au endpoint et récupération des informations
        Renvoie une liste d'objets SummerVolume
        """
        logger.debug("Getting the list of volumes")
        for _, vol in self.volumes.items():
            logger.debug("Fetching %s", vol.name)
            _, ssh_stdout, _ = self.client.exec_command(f"volume show -volume {vol.id}")
            for eline in ssh_stdout.readlines():
                if re.search('^\s+Total User-Visible Size:', eline):
                    logger.debug(eline)
                    size_with_unit = re.split(r":\s+", eline.rstrip())[-1]
                    vol.set_value('total_size', to_bytes(size_with_unit))
                    continue
                if re.search('^\s+Used Size:', eline):
                    logger.debug(eline)
                    size_with_unit = re.split(r":\s+", eline.rstrip())[-1]
                    vol.set_value('used_size', to_bytes(size_with_unit))
                    continue
                if re.search('^\s+Available Size:', eline):
                    logger.debug(eline)
                    size_with_unit = re.split(r":\s+", eline.rstrip())[-1]
                    vol.set_value('available_size', to_bytes(size_with_unit))
                    continue
                if re.search('^\s+Available Snapshot Reserve Size:', eline):
                    logger.debug(eline)
                    size_with_unit = re.split(r":\s+", eline.rstrip())[-1]
                    vol.set_value('snapshot_reserve', to_bytes(size_with_unit))
                    continue
                if re.search('^\s+Volume Size Used by Snapshot Copies', eline):
                    logger.debug(eline)
                    size_with_unit = re.split(r":\s+", eline.rstrip())[-1]
                    vol.set_value('snapshot_size', to_bytes(size_with_unit))
                    continue
            logger.debug("Volume: %s", vol)

    def zabbix_lld(self):
        return self.volumes.zabbix_lld(self.prefix)
